pub enum Operation<Key, Value> {
Set(Key, Value),
Dereference(Key),
Reference(Key),
}Expand description
Different operations allowed for a commit. Behavior may differs depending on column configuration.
Variants
Set(Key, Value)
Insert or update the value for a given key.
Dereference(Key)
Dereference at a given key, resulting in either removal of a key value or decrement of its reference count counter.
Reference(Key)
Increment the reference count counter of an existing value for a given key. If no value exists for the key, this operation is skipped.
Implementations