Struct parity_db::ColumnOptions
source · [−]pub struct ColumnOptions {
pub preimage: bool,
pub uniform: bool,
pub ref_counted: bool,
pub compression: CompressionType,
pub btree_index: bool,
}Fields
preimage: boolIndicates that the column value is the preimage of the key. This implies that a given value always has the same key. Enables some optimizations.
uniform: boolIndicates that the keys are at least 32 bytes and the first 32 bytes have uniform distribution. Allows for skipping additional key hashing.
ref_counted: boolUse reference counting for values.
Reference counting do not enforce immediate removal and user should not check for missing value.
compression: CompressionTypeCompression to use for this column.
btree_index: boolColumn is using a btree indexing.
Implementations
sourceimpl ColumnOptions
impl ColumnOptions