pub struct ColumnStatSummary {
    pub total_values: u64,
    pub total_bytes: u64,
    pub uncompressed_bytes: u64,
}
Column statistics summary.

Fields

total_values: u64

Current number of values in the column.

total_bytes: u64

Total size of (compressed) values in the column. This does not include key size and any other overhead.

uncompressed_bytes: u64

Total size of values in the column before compression. This does not include key size and any other overhead.