Struct parity_db::ColumnOptions[][src]

pub struct ColumnOptions {
    pub preimage: bool,
    pub uniform: bool,
    pub sizes: Vec<u16>,
    pub ref_counted: bool,
    pub compression: CompressionType,
    pub compression_treshold: u32,
}

Fields

preimage: bool

Indicates that the column value is the preimage of the key. This implies that a given value always has the same key. Enables some optimizations.

uniform: bool

Indicates that the keys are at least 32 bytes and the first 32 bytes have uniform distribution. Allows for skipping additional key hashing.

sizes: Vec<u16>

Value size tiers.

ref_counted: bool

Use reference counting for values.

compression: CompressionType

Compression to use for this column.

compression_treshold: u32

Minimal value size threshold to attempt compressing a value.

Implementations