Struct parity_db::ColumnOptions [−][src]
pub struct ColumnOptions {
pub preimage: bool,
pub uniform: bool,
pub sizes: [u16; 15],
pub ref_counted: bool,
}Fields
preimage: boolIndicates that the column value is the preimage of the key. This implies that a given value always has the same key. Enables some optimizations.
uniform: boolIndicates that the keys are at least 32 bytes and the first 32 bytes have uniform distribution. Allows for skipping additional key hashing.
sizes: [u16; 15]Value size tiers.
ref_counted: boolUse referece counting for values.