Struct parity_db::ColumnStatSummary
source · [−]pub struct ColumnStatSummary {
pub total_values: u64,
pub total_bytes: u64,
pub uncompressed_bytes: u64,
}Expand description
Column statistics summary.
Fields
total_values: u64Current number of values in the column.
total_bytes: u64Total size of (compressed) values in the column. This does not include key size and any other overhead.
uncompressed_bytes: u64Total size of values in the column before compression. This does not include key size and any other overhead.