Struct parity_db::Db

source ·
pub struct Db { /* private fields */ }

Implementations

Open the database with given options.

Create the database using given options.

Read the database using given options

Get a value in a specified column by key. Returns None if the key does not exist.

Get value size by key. Returns None if the key does not exist.

Iterate over all ordered key-value pairs. Only supported for columns configured with btree_indexed.

Commit a set of changes to the database.

Commit a set of changes to the database.

Returns the number of columns in the database.

Iterate a column and call a function for each value. This is only supported for columns with btree_index set to false. Iteration order is unspecified. Note that the key field in the state is the hash of the original key. Unlinke get the iteration may not include changes made in recent commit calls.

Print database contents in text form to stderr.

Get database statistics.

Add a new column with options specified by new_column_options.